==> 1.0.124.tar.gz: lib/modules/shared_product/shared_product_repo.dart <==
import 'package:b2b_graphql_package/GraphQLConfiguration.dart';
import 'package:b2b_graphql_package/modules/shared_product/shared_product_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

class SharedProductRepo {
  var graphQLConfiguration;
  var productList;
  SharedProductRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }
  Future getSharedProduct(int limit, int pageNo, String userId) async {
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    String getSharedProductWithPagination = """
        query getAllSharedProductWithPagination(\$limit: Int, \$pageNo: Int, \$userId: String) {
        getAllSharedProductWithPagination(limit: \$limit, pageNo: \$pageNo, userId: \$userId) {
                       _id
                       userId
                       productId {
                          _id
                        productId
                        name
                        description
                        imageId
                        type
                        moq
                        isOutofstock
                        isMultiple
                        price {
                          sellingPrice
                          mrp
                          discount
                          minPrice
                          maxPrice
                          type
                          isSamePrice
                          __typename
                        }
                        images {
                          imageName
                          position
                          __typename
                        }
                        __typename
                       }
          }
        }
        """;
    final variable = {"limit": limit, "pageNo": pageNo, "userId": userId};
    QueryResult result = await _client.query(QueryOptions(
        document: gql(getSharedProductWithPagination),
        variables: variable,
        fetchPolicy: FetchPolicy.networkOnly));
    if (!result.hasException) {
      var products = result.data!['getAllSharedProductWithPagination'];
      if (products != null && products.length > 0) {
        productList = sharedProductFromJson(products);
      }

      return productList;
    }
    return productList;
  }
}

Future updateSharedCatalog(String userId, String productId) async {
  GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
  GraphQLClient _client = graphQLConfiguration.clientToQuery();
  String updateSharedCatalogQuery = """
            mutation updateSharedCatalog(\$productId: String, \$userId: String) {
              updateSharedCatalog(productId: \$productId, userId: \$userId) {
                _id
              }
            }
            """;
  final variables = {userId: userId, productId: productId};
  var response;
  QueryResult result = await _client.mutate(MutationOptions(
      document: gql(updateSharedCatalogQuery), variables: variables));
  if (result.hasException) {
    response = result.data!['updateSharedCatalog'];
  }
  return response;
}

==> 1.0.128.tar.gz: lib/modules/shared_product/shared_product_repo.dart <==
import 'package:b2b_graphql_package/GraphQLConfiguration.dart';
import 'package:b2b_graphql_package/modules/shared_product/shared_product_model.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

class SharedProductRepo {
  var graphQLConfiguration;
  var productList = [];
  SharedProductRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }
  Future getSharedProduct(int limit, int pageNo, String userId) async {
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    String getSharedProductWithPagination = """
        query getAllSharedProductWithPagination(\$limit: Int, \$pageNo: Int, \$userId: String) {
        getAllSharedProductWithPagination(limit: \$limit, pageNo: \$pageNo, userId: \$userId) {
                       _id
                       userId
                       productId {
                          _id
                        productId
                        name
                        description
                        imageId
                        type
                        moq
                        isOutofstock
                        isMultiple
                        price {
                          sellingPrice
                          mrp
                          discount
                          minPrice
                          maxPrice
                          type
                          isSamePrice
                          __typename
                        }
                        images {
                          imageName
                          position
                          __typename
                        }
                        __typename
                       }
          }
        }
        """;
    final variable = {"limit": limit, "pageNo": pageNo, "userId": userId};
    QueryResult result = await _client.query(QueryOptions(
        document: gql(getSharedProductWithPagination),
        variables: variable,
        fetchPolicy: FetchPolicy.networkOnly));
    if (!result.hasException) {
      var products = result.data!['getAllSharedProductWithPagination'];
      if (products != null && products.length > 0) {
        productList = sharedProductFromJson(products);
      }

      return productList;
    }
    return productList;
  }

  Future updateSharedCatalog(String userId, String productId) async {
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    String updateSharedCatalogQuery = """
            mutation updateSharedCatalog(\$productId: String, \$userId: String) {
              updateSharedCatalog(productId: \$productId, userId: \$userId) {
                _id
              }
            }
            """;
    final variables = {"userId": userId, "productId": productId};
    var response;
    QueryResult result = await _client.mutate(MutationOptions(
        document: gql(updateSharedCatalogQuery), variables: variables));
    if (result.hasException) {
      response = result.data!['updateSharedCatalog'];
    }
    return response;
  }
}
